@@ -4,7 +4,7 @@ using namespace Rcpp;
 #include <PoissonBinomial.h>
 using namespace PoissonBinomial;
 
-NumericVector poibinom_int(NumericVector probs, int method, int max_q);
+NumericVector poibinom_int(NumericVector probs, int method, int max_q, bool lower_tail = true);
 
 //NumericVector dpbinom(IntegerVector obs, NumericVector probs, int method);
 
